pub enum SLTForEffect {
Event {
site_id: u32,
guard: Option<NodeId>,
emit_on_true: bool,
args: Vec<NodeId>,
fatal_error_code: Option<i64>,
},
Runner(NodeId),
}Variants
Event
Emit one runtime event for the current loop iteration.
Fields
Runner(NodeId)
Evaluate a nested loop runner at this position in the effect sequence.