pub enum SLTForFoldResult<A: Hash + Eq + Clone> {
State(VarAtomBase<A>),
Transient {
initial: NodeId,
update: NodeId,
},
}Expand description
Selects the value returned by a legacy dynamic loop fold.
Most folds return one of their variable-backed states. Control-flow lowering can instead carry a transient value which has no semantic HDL variable and therefore must not be represented by a fabricated bit range.
Variants