pub struct SLTForFoldGroupState<A: Hash + Eq + Clone> {
pub target: VarAtomBase<A>,
pub initial: NodeId,
pub update: NodeId,
}Expand description
One loop-carried state in a grouped fixed-trip-count fold.
initial is evaluated before entering the loop and update is evaluated
once per iteration with all state targets bound to the previous iteration’s
values. A SLTNode::ForFoldGroup packs the final values in states
order, with the first state occupying the most-significant bits.
Fields
target: VarAtomBase<A>initial: NodeIdupdate: NodeIdTrait Implementations
Sourceimpl<A: Clone + Hash + Eq + Clone> Clone for SLTForFoldGroupState<A>
impl<A: Clone + Hash + Eq + Clone> Clone for SLTForFoldGroupState<A>
Sourcefn clone(&self) -> SLTForFoldGroupState<A>
fn clone(&self) -> SLTForFoldGroupState<A>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de, A> Deserialize<'de> for SLTForFoldGroupState<A>
impl<'de, A> Deserialize<'de> for SLTForFoldGroupState<A>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<A: Eq + Hash + Eq + Clone> Eq for SLTForFoldGroupState<A>
Sourceimpl<A> Serialize for SLTForFoldGroupState<A>
impl<A> Serialize for SLTForFoldGroupState<A>
impl<A: PartialEq + Hash + Eq + Clone> StructuralPartialEq for SLTForFoldGroupState<A>