pub struct RangeStore<T> {
pub ranges: BTreeMap<usize, (T, usize, usize)>,
}Fields
ranges: BTreeMap<usize, (T, usize, usize)>key: lsb (absolute position) value: (expression, width, origin LSB when this data was originally placed)
Implementations
Sourceimpl<T> RangeStore<T>
impl<T> RangeStore<T>
Sourcepub fn aligned_parts<'a, U>(
&'a self,
other: &'a RangeStore<U>,
) -> Result<Vec<AlignedRangePart<'a, T, U>>, RangeStoreError>
pub fn aligned_parts<'a, U>( &'a self, other: &'a RangeStore<U>, ) -> Result<Vec<AlignedRangePart<'a, T, U>>, RangeStoreError>
Align two sparse partitions in one ordered pass.
Each returned absolute range is bounded by the next boundary from either store. The accompanying accesses are relative to each value’s original placement, so callers can slice the values without searching either map again.
Sourceimpl<T: Clone + PartialEq + Eq> RangeStore<T>
impl<T: Clone + PartialEq + Eq> RangeStore<T>
pub fn new(initial: T, width: usize) -> Self
Sourcepub fn split_at(&mut self, bit: usize) -> Result<(), RangeStoreError>
pub fn split_at(&mut self, bit: usize) -> Result<(), RangeStoreError>
Split the range at the specified bit position. Even if split, origin_lsb (the 3rd element) is maintained.
Sourcepub fn update(
&mut self,
access: BitAccess,
value: T,
) -> Result<(), RangeStoreError>
pub fn update( &mut self, access: BitAccess, value: T, ) -> Result<(), RangeStoreError>
Update the specified range with a new value. The origin_lsb of the updated range will match access.lsb of that assignment.
Sourcepub fn get_parts_ref(
&self,
access: BitAccess,
) -> Result<Vec<(&T, BitAccess)>, RangeStoreError>
pub fn get_parts_ref( &self, access: BitAccess, ) -> Result<Vec<(&T, BitAccess)>, RangeStoreError>
Returns borrowed parts overlapping with the requested range. relative_access will be the relative position from the origin of that expression.